==> compass-service-0.1.102-sources.jar: com/xforceplus/compass/controller/YearBillDetailController.java <==
package com.xforceplus.compass.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.compass.entity.YearBillDetail;
import com.xforceplus.compass.service.IYearBillDetailService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2022-08-08
 */
@RestController
public class YearBillDetailController {

  @Autowired
  private IYearBillDetailService yearBillDetailServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param yearBillDetail ${table.comment}
   * @return
   */
  @GetMapping("/yearbilldetails" )
  public XfR getYearBillDetails(XfPage page, YearBillDetail yearBillDetail) {
    return XfR.ok(yearBillDetailServiceImpl.page(page, Wrappers.query(yearBillDetail)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/yearbilldetails/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(yearBillDetailServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param yearBillDetail ${table.comment}
   * @return XfR
   */
  @PostMapping("/yearbilldetails")
  public XfR save(@RequestBody YearBillDetail yearBillDetail) {
     return XfR.ok(yearBillDetailServiceImpl.save(yearBillDetail));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param yearBillDetail ${table.comment}
   * @return XfR
   */
  @PutMapping("/yearbilldetails/{id}")
  public XfR putUpdate(@RequestBody YearBillDetail yearBillDetail,@PathVariable Long id) {
      yearBillDetail.setId(id);
      return XfR.ok(yearBillDetailServiceImpl.updateById(yearBillDetail));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param yearBillDetail ${table.comment}
   * @return XfR
   */
  @PatchMapping("/yearbilldetails/{id}")
  public XfR patchUpdate(@RequestBody YearBillDetail yearBillDetail,@PathVariable Long id) {
      YearBillDetail upyearBillDetail = yearBillDetailServiceImpl.getById(id);
      if(upyearBillDetail != null){
        upyearBillDetail = ObjectCopyUtils.copyProperties(yearBillDetail,upyearBillDetail,true);
      }
      return XfR.ok(yearBillDetailServiceImpl.updateById(upyearBillDetail));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/yearbilldetails/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(yearBillDetailServiceImpl.removeById(id));
  }

  @PostMapping("/yearbilldetails/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "year_bill_detail");
     params.put("request", condition);

     return XfR.ok(yearBillDetailServiceImpl.querys(params));
  }

}

==> compass-service-0.1.182-sources.jar: com/xforceplus/compass/controller/YearBillDetailController.java <==
package com.xforceplus.compass.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.compass.entity.YearBillDetail;
import com.xforceplus.compass.service.IYearBillDetailService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;

/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2025-05-19
 */
@RestController
public class YearBillDetailController {

  @Autowired
  private IYearBillDetailService yearBillDetailServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param yearBillDetail ${table.comment}
   * @return
   */
  @GetMapping("/yearbilldetails" )
  public XfR getYearBillDetails(XfPage page, YearBillDetail yearBillDetail) {
    return XfR.ok(yearBillDetailServiceImpl.page(page, Wrappers.query(yearBillDetail)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/yearbilldetails/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(yearBillDetailServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param yearBillDetail ${table.comment}
   * @return XfR
   */
  @PostMapping("/yearbilldetails")
  public XfR save(@RequestBody YearBillDetail yearBillDetail) {
     return XfR.ok(yearBillDetailServiceImpl.save(yearBillDetail));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param yearBillDetail ${table.comment}
   * @return XfR
   */
  @PutMapping("/yearbilldetails/{id}")
  public XfR putUpdate(@RequestBody YearBillDetail yearBillDetail,@PathVariable Long id) {
      yearBillDetail.setId(id);
      return XfR.ok(yearBillDetailServiceImpl.updateById(yearBillDetail));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param yearBillDetail ${table.comment}
   * @return XfR
   */
  @PatchMapping("/yearbilldetails/{id}")
  public XfR patchUpdate(@RequestBody YearBillDetail yearBillDetail,@PathVariable Long id) {
      YearBillDetail upyearBillDetail = yearBillDetailServiceImpl.getById(id);
      if(upyearBillDetail != null){
        upyearBillDetail = ObjectCopyUtils.copyProperties(yearBillDetail,upyearBillDetail,true);
      }
      return XfR.ok(yearBillDetailServiceImpl.updateById(upyearBillDetail));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/yearbilldetails/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(yearBillDetailServiceImpl.removeById(id));
  }

  @PostMapping("/yearbilldetails/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "year_bill_detail");
     params.put("request", condition);

     return XfR.ok(yearBillDetailServiceImpl.querys(params));
  }

}
